/*
 * [AustraliaDay.java]
 *
 * Summary: calculate when Australia day occurs.
 *
 * Copyright: (c) 1999-2011 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.5+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  4.2 2008-12-03 add World AIDS day
 */
package com.mindprod.holidays;

import com.mindprod.common11.BigDate;

/**
 * calculate when Australia day occurs.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 4.2 2008-12-03 add World AIDS day
 * @see ANZACDay
 * @since 1999
 */
public final class AustraliaDay extends HolInfo
    {
    // -------------------------- PUBLIC INSTANCE  METHODS --------------------------

    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "http://www.australiaday.gov.au/pages/page20.asp";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 1804;
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "Australia Day";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        return "Celebrated January 26, the anniversary of Captain Arthur Phillip\n" +
               "arriving in Sydney Cove on 1788-01-26.\n" +
               "Originally called First Landing Day or Foundation Day.";
        }

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        return shiftSatToFriSunToMon( BigDate.toOrdinal( year, 1, 26 ), shift );
        }// end when.
    }
