/*
 * [MemorialDay.java]
 *
 * Summary: calculate when Memorial day occurs.
 *
 * Copyright: (c) 1999-2011 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.5+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  4.2 2008-12-03 add World AIDS day
 */
package com.mindprod.holidays;

import com.mindprod.common11.BigDate;

/**
 * calculate when Memorial day occurs.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 4.2 2008-12-03 add World AIDS day
 * @since 1999
 */
public final class MemorialDay extends HolInfo
    {
    // -------------------------- PUBLIC INSTANCE  METHODS --------------------------

    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "http://www.geocities.com/~angel-pie/memorial/origins.html";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 1868;
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "Memorial Day";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        return "Last Monday in May. Originally May 31";
        }

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        return BigDate.ordinalOfnthXXXDay( 5, BigDate.MONDAY, year, BigDate.MAY );
        }// end when.
    }
