/*
 * [QueensBirthday.java]
 *
 * Summary: calculate when The Queen's Birthday is celebrated is Australia.
 *
 * Copyright: (c) 1999-2011 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.5+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  4.2 2008-12-03 add World AIDS day
 */
package com.mindprod.holidays;

import com.mindprod.common11.BigDate;

/**
 * calculate when The Queen's Birthday is celebrated is Australia.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 4.2 2008-12-03 add World AIDS day
 * @since 1999
 */
public final class QueensBirthday extends HolInfo
    {
    // -------------------------- PUBLIC INSTANCE  METHODS --------------------------

    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "http://en.wikipedia.org/wiki/Public_holidays_in_Australia";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 1953;
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "Australian Queen\u2019s Birthday";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        return "Second Monday in June. The official birthday, not Queen Elizabeth\u2019s actual birthday.";
        }

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        return BigDate.ordinalOfnthXXXDay( 2, BigDate.MONDAY, year, BigDate.JUN );
        }// end when.
    }
